@@ -4,18 +4,24 @@ class FaceCompareResult:
     # ERROR_CODE_
     CALL_STATUS_SUCCESS = 0
     CALL_STATUS_ERROR = -1
+    RESULT_SAME_FACE = 1
+    RESULT_DIFFERENT_FACE = -1
 
-    def __init__(self, result=None, distance_min=None, distance_mean=None, distance_max=None,
-                 second_validation_result=None,
-                 first_validation_result=None, status=CALL_STATUS_ERROR, message=""):
+    def __init__(
+        self,
+        result=RESULT_DIFFERENT_FACE,
+        distance=None,
+        second_validation_result=None,
+        first_validation_result=None,
+        status=CALL_STATUS_ERROR,
+        message="",
+    ):
         """Result handler for compare
         """
         self._status = status
         self._result = result
-        self._message = message
-        self._distance_min = distance_min
-        self._distance_mean = distance_mean
-        self._distance_max = distance_max
+        self._message = message        
+        self._distance = distance
         self._first_validation_result = first_validation_result
         self._second_validation_result = second_validation_result
 
@@ -24,9 +30,9 @@ class FaceCompareResult:
         """
         Returns the status of the operation
 
-        0 - If successfully obtained result from server
+        0 - If the compare call was successful (regardless of the result)
 
-        -1 - In case of error
+        -1 - In case of error and the compare was not performed because of an error
 
         """
         return self._status
@@ -35,6 +41,8 @@ class FaceCompareResult:
     def result(self) -> int:
         """
         Returns the result of the operation
+        1  - if 2 images are same
+        -1 - if 2 images are different
         """
         return self._result
 
@@ -46,34 +54,12 @@ class FaceCompareResult:
         return self._message
 
     @property
-    def distance_min(self) -> float:
+    def distance(self) -> float:
         """
-        Returns the minimum distance
-
-        Minimum distance refers to the thresholds used for comparing the images
-
+        Returns the comparaison distance
+        
         """
-        return self._distance_min
-
-    @property
-    def distance_mean(self) -> float:
-        """
-        Returns the average distance
-
-        Mean distance refers to the thresholds used for comparing the images
-
-        """
-        return self._distance_mean
-
-    @property
-    def distance_max(self) -> float:
-        """
-        Returns the maximum distance
-
-        Maximum distance refers to the thresholds used for comparing the images
-
-        """
-        return self._distance_max
+        return self._distance
 
     @property
     def first_validation_result(self) -> int:
@@ -101,18 +87,11 @@ class FaceCompareResult:
     def message(self, value):
         self._message = value
 
-    @distance_min.setter
-    def distance_min(self, value):
-        self._distance_min = value
-
-    @distance_mean.setter
-    def distance_mean(self, value):
-        self._distance_mean = value
-
-    @distance_max.setter
-    def distance_max(self, value):
-        self._distance_max = value
+    @distance.setter
+    def distance(self, value):
+        self._distance = value
 
+    
     @first_validation_result.setter
     def first_validation_result(self, value):
         self._first_validation_result = value
